@@ -1,2 +1,4 @@
 """This is the autogluon version file."""
-__version__ = '0.6.1'
+
+__version__ = "1.4.0"
+__lite__ = False
